@@ -1,5 +1,5 @@
 #coding = utf-8
-__version__ = '0.3.11'
+__version__ = '0.3.12'
 
 import random
 from termcolor import colored, cprint
@@ -234,7 +234,7 @@ def EndScreen(turn, gameManager, p1, p2, p):
         if mode == 1:
             eraseDatas(turn, gameManager, p1, p2, p)
         if mode == 2:
-            setIcon(platform.system(), pathToScript)
+            setIcon(sys, pathToScript)
 
 if __name__ == "__main__":
     os.chdir(pathToScript)
